.. Copyright (C) 2019, Nokia

.. crl.remotescript documentation master file, created by
   sphinx-quickstart on Fri Apr  1 15:31:00 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to crl.remotescript's documentation!
============================================

Contents:

.. toctree::
   :maxdepth: 2

   robotdocs
   Readme <README>
   Change History <CHANGES>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
